@@ -55,7 +55,7 @@
  */
 
 /*
- * $Id: DOMNodeImpl.cpp,v 1.24 2003/04/03 19:25:50 peiyongz Exp $
+ * $Id: DOMNodeImpl.cpp,v 1.26 2003/10/23 21:19:58 amassari Exp $
  */
 
 // This class doesn't support having any children, and implements the behavior
@@ -441,8 +441,9 @@ void DOMNodeImpl::callUserDataHandlers(DOMUserDataHandler::DOMOperationType oper
                                        const DOMNode* src,
                                        const DOMNode* dst) const
 {
-    if (((DOMDocumentImpl*)getOwnerDocument()))
-        ((DOMDocumentImpl*)getOwnerDocument())->callUserDataHandlers(this, operation, src, dst);
+    DOMDocumentImpl* doc=(DOMDocumentImpl*)getOwnerDocument();
+    if (doc)
+        doc->callUserDataHandlers(this, operation, src, dst);
 }
 
 bool DOMNodeImpl::isSameNode(const DOMNode* other) const
@@ -950,12 +951,10 @@ short DOMNodeImpl::reverseTreeOrderBitPattern(short pattern) const {
 
 const XMLCh*     DOMNodeImpl::getTextContent() const
 {
-
 	unsigned int nBufferLength = 0;
 
 	getTextContent(NULL, nBufferLength);
-	XMLCh* pzBuffer = (XMLCh*)((DOMDocumentImpl*)getOwnerDocument())->allocate(nBufferLength+1);
-
+	XMLCh* pzBuffer = (XMLCh*)((DOMDocumentImpl*)getOwnerDocument())->allocate((nBufferLength+1) * sizeof(XMLCh));
 	getTextContent(pzBuffer, nBufferLength);
 	pzBuffer[nBufferLength] = 0;
 
