@@ -55,8 +55,29 @@
  */
 
 /*
- * $Id: DOMWriterImpl.cpp,v 1.39 2003/05/18 14:02:03 knoaman Exp $
+ * $Id: DOMWriterImpl.cpp,v 1.46 2003/11/24 19:52:22 neilg Exp $
  * $Log: DOMWriterImpl.cpp,v $
+ * Revision 1.46  2003/11/24 19:52:22  neilg
+ * fix a typo
+ *
+ * Revision 1.45  2003/11/24 12:27:57  gareth
+ * added in support for xml-declaration feature.
+ *
+ * Revision 1.44  2003/11/24 11:10:58  gareth
+ * Fix for bug 22917. Patch by Adam Heinz .
+ *
+ * Revision 1.43  2003/11/10 17:52:58  amassari
+ * Fixed memory leak
+ *
+ * Revision 1.42  2003/10/01 16:32:37  neilg
+ * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
+ *
+ * Revision 1.41  2003/08/14 16:31:13  gareth
+ * Method added to allow serilization of custom nodes from derived classes.
+ *
+ * Revision 1.40  2003/08/12 12:46:57  gareth
+ * Added serialization for attribute nodes. Patch by Caroline Rioux.
+ *
  * Revision 1.39  2003/05/18 14:02:03  knoaman
  * Memory manager implementation: pass per instance manager.
  *
@@ -197,7 +218,7 @@
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLMsgLoader.hpp>
 #include <xercesc/dom/StDOMNode.hpp>
-
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -217,6 +238,7 @@ static const int SPLIT_CDATA_SECTIONS_ID          = 0x5;
 static const int VALIDATION_ID                    = 0x6;
 static const int WHITESPACE_IN_ELEMENT_CONTENT_ID = 0x7;
 static const int BYTE_ORDER_MARK_ID               = 0x8;
+static const int XML_DECLARATION                 = 0x9;
 
 //    feature                      true                       false
 // ================================================================================
@@ -244,7 +266,8 @@ static const bool  featuresSupported[] = {
     true,  true,  // split-cdata-sections
     false, true,  // validation
     true,  false, // whitespace-in-element-content
-    true,  true   // byte-order-mark
+    true,  true,   // byte-order-mark
+    true,  true   // xml-declaration
 };
 
 // default end-of-line sequence
@@ -494,6 +517,8 @@ DOMWriterImpl::DOMWriterImpl(MemoryManager* const manager)
     setFeature(VALIDATION_ID,                    false);
     setFeature(WHITESPACE_IN_ELEMENT_CONTENT_ID, true );
     setFeature(BYTE_ORDER_MARK_ID,               false);
+    setFeature(XML_DECLARATION,                 true );
+
 }
 
 bool DOMWriterImpl::canSetFeature(const XMLCh* const featName
@@ -633,7 +658,10 @@ bool DOMWriterImpl::writeNode(XMLFormatTarget* const destination
         destination->flush();
         return false;
     }
-
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     //
     // DOMSystemException
     // This exception will be raised in response to any sort of IO or system
@@ -674,6 +702,10 @@ XMLCh* DOMWriterImpl::writeToString(const DOMNode &nodeToWrite)
     {
         retVal = writeNode(&destination, nodeToWrite);
     }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch (...)
     {
         //
@@ -685,7 +717,7 @@ XMLCh* DOMWriterImpl::writeToString(const DOMNode &nodeToWrite)
     }
 
     fEncoding = tempEncoding;
-    return (retVal ? XMLString::replicate((XMLCh*) destination.getRawBuffer()) : 0);
+    return (retVal ? XMLString::replicate((XMLCh*) destination.getRawBuffer(), fMemoryManager) : 0);
 }
 
 void DOMWriterImpl::initSession(const DOMNode* const nodeToWrite)
@@ -814,8 +846,8 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
             if (checkFilter(nodeToWrite) != DOMNodeFilter::FILTER_ACCEPT)
                 break;
 
-            //skip ws if pretty print
-            if (getFeature(FORMAT_PRETTY_PRINT_ID))
+            // Pretty-print skips whitespace-only text nodes unless whitespace-in-element is set.
+            if (getFeature(FORMAT_PRETTY_PRINT_ID) && !getFeature(WHITESPACE_IN_ELEMENT_CONTENT_ID))
             {
                 if(XMLString::isAllWhiteSpace(nodeValue))
                     break;
@@ -864,19 +896,19 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
             //[80] EncodingDecl ::= S 'encoding' Eq ('"' EncName '"' | "'" EncName
             //[32] SDDecl       ::= S 'standalone' Eq (("'" ('yes' | 'no') "'") | ('"' ('yes' | 'no') '"'))
             //
-            // We always print out the xmldecl no matter whether it is
-            // present in the original XML instance document or not.
-            //
-            const XMLCh* versionNo = (docu->getVersion()) ? docu->getVersion() : gXMLDecl_ver10;
-            *fFormatter << gXMLDecl_VersionInfo << versionNo << gXMLDecl_separator;
 
-            // use the encoding resolved in initSession()
-            *fFormatter << gXMLDecl_EncodingDecl << fEncodingUsed << gXMLDecl_separator;
+            if (getFeature(XML_DECLARATION)) {
+                const XMLCh* versionNo = (docu->getVersion()) ? docu->getVersion() : gXMLDecl_ver10;
+                *fFormatter << gXMLDecl_VersionInfo << versionNo << gXMLDecl_separator;
 
-            const XMLCh* st = (docu->getStandalone())? XMLUni::fgYesString : XMLUni::fgNoString;
-            *fFormatter << gXMLDecl_SDDecl << st << gXMLDecl_separator;
+                // use the encoding resolved in initSession()
+                *fFormatter << gXMLDecl_EncodingDecl << fEncodingUsed << gXMLDecl_separator;
 
-            *fFormatter << gXMLDecl_endtag;
+                const XMLCh* st = (docu->getStandalone())? XMLUni::fgYesString : XMLUni::fgNoString;
+                *fFormatter << gXMLDecl_SDDecl << st << gXMLDecl_separator;
+                
+                *fFormatter << gXMLDecl_endtag;
+            }
 
             DOMNodeSPtr child = nodeToWrite->getFirstChild();
             while( child != 0)
@@ -1131,7 +1163,35 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
 
             break;
         }
+    case DOMNode::ATTRIBUTE_NODE:
+        {
+            if (checkFilter(nodeToWrite) != DOMNodeFilter::FILTER_ACCEPT)
+                break;
 
+            const XMLCh* localName = nodeToWrite->getLocalName();
+
+            // check if this is a DOM Level 1 Node
+            if(localName == 0) {
+                *fFormatter  << XMLFormatter::NoEscapes
+                             << nodeToWrite->getNodeName()
+                             << chEqual << chDoubleQuote
+                             << XMLFormatter::AttrEscapes
+                             << nodeToWrite->getNodeValue()
+                             << XMLFormatter::NoEscapes
+                             << chDoubleQuote;
+            } else {
+                *fFormatter  << XMLFormatter::NoEscapes
+                             << chOpenCurly << nodeToWrite->getNamespaceURI() 
+                             << chCloseCurly << localName
+                             << chEqual << chDoubleQuote
+                             << XMLFormatter::AttrEscapes
+                             << nodeToWrite->getNodeValue()
+                             << XMLFormatter::NoEscapes
+                             << chDoubleQuote;
+            }
+
+            break;
+        }
     case DOMNode::ENTITY_REFERENCE_NODE:
         {
             //"entities"
@@ -1336,12 +1396,14 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
 
     default:
         /***
-            This is an implementation specific behaviour, we abort serialization
-            once unrecognized node type encountered.
+            This is an implementation specific behaviour, we abort if a user derived class has not dealt with
+            this node type.
          ***/
         {
-            reportError(nodeToWrite, DOMError::DOM_SEVERITY_FATAL_ERROR, XMLDOMMsg::Writer_NotRecognizedType);
-            // UnreognizedNodeType;
+            if(!customNodeSerialize(nodeToWrite, level)) {
+                reportError(nodeToWrite, DOMError::DOM_SEVERITY_FATAL_ERROR, XMLDOMMsg::Writer_NotRecognizedType);
+                // UnreognizedNodeType;
+            }
         }
 
         break;
@@ -1349,6 +1411,10 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
 
 }
 
+bool DOMWriterImpl::customNodeSerialize(const DOMNode* const nodeToWrite, int level) {
+    return false;
+}
+
 //
 //
 DOMNodeFilter::FilterAction DOMWriterImpl::checkFilter(const DOMNode* const node) const
@@ -1399,6 +1465,9 @@ bool DOMWriterImpl::checkFeature(const XMLCh* const featName
         featureId = WHITESPACE_IN_ELEMENT_CONTENT_ID;
     else if (XMLString::equals(featName, XMLUni::fgDOMWRTBOM))
         featureId = BYTE_ORDER_MARK_ID;
+    else if (XMLString::equals(featName, XMLUni::fgDOMXMLDeclaration))
+        featureId = XML_DECLARATION;
+
 
     //feature name not resolvable
     if (featureId == INVALID_FEATURE_ID)
