@@ -55,7 +55,7 @@
  */
 
 /**
- * $Id: XMLElementDecl.cpp,v 1.6 2003/05/18 14:02:04 knoaman Exp $
+ * $Id: XMLElementDecl.cpp,v 1.7 2003/10/10 16:23:29 peiyongz Exp $
  */
 
 
@@ -135,5 +135,35 @@ XMLElementDecl::XMLElementDecl(MemoryManager* const manager) :
 {
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_NOCREATE(XMLElementDecl)
+
+void XMLElementDecl::serialize(XSerializeEngine& serEng)
+{
+
+    if (serEng.isStoring())
+    {
+        serEng<<fElementName;
+        serEng<<(int) fCreateReason;
+        serEng<<fId;
+        serEng<<fExternalElement;
+    }
+    else
+    {
+        serEng>>fElementName;
+
+        int i;
+        serEng>>i;
+        fCreateReason=(CreateReasons)i;
+
+        serEng>>fId;
+        serEng>>fExternalElement;
+    }
+
+}
+
 XERCES_CPP_NAMESPACE_END
 
