@@ -55,7 +55,7 @@
  */
 
 /*
-  * $Id: WFXMLScanner.cpp,v 1.12 2003/05/18 14:02:04 knoaman Exp $
+  * $Id: WFXMLScanner.cpp,v 1.17 2003/11/01 20:24:22 amassari Exp $
  */
 
 
@@ -72,7 +72,7 @@
 #include <xercesc/framework/XMLPScanToken.hpp>
 #include <xercesc/framework/XMLValidityCodes.hpp>
 #include <xercesc/internal/EndOfEntityException.hpp>
-
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -80,21 +80,25 @@ XERCES_CPP_NAMESPACE_BEGIN
 //  WFXMLScanner: Constructors and Destructor
 // ---------------------------------------------------------------------------
 WFXMLScanner::WFXMLScanner( XMLValidator* const  valToAdopt
+                          , GrammarResolver* const grammarResolver
                           , MemoryManager* const manager) :
 
-    XMLScanner(valToAdopt, manager)
+    XMLScanner(valToAdopt, grammarResolver, manager)
     , fElementIndex(0)
     , fElements(0)
     , fEntityTable(0)
     , fAttrNameHashList(0)
     , fAttrNSList(0)
     , fElementLookup(0)
-    , fElemStack(manager)
 {
     try
     {
         commonInit();
     }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch(...)
     {
         cleanUp();
@@ -107,21 +111,25 @@ WFXMLScanner::WFXMLScanner( XMLDocumentHandler* const docHandler
                           , XMLEntityHandler* const   entityHandler
                           , XMLErrorReporter* const   errHandler
                           , XMLValidator* const       valToAdopt
+                          , GrammarResolver* const    grammarResolver
                           , MemoryManager* const      manager) :
 
-    XMLScanner(docHandler, docTypeHandler, entityHandler, errHandler, valToAdopt, manager)
+    XMLScanner(docHandler, docTypeHandler, entityHandler, errHandler, valToAdopt, grammarResolver, manager)
     , fElementIndex(0)
     , fElements(0)
     , fEntityTable(0)
     , fAttrNameHashList(0)
     , fAttrNSList(0)
     , fElementLookup(0)
-    , fElemStack(manager)
 {
     try
     {	
         commonInit();
     }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch(...)
     {
         cleanUp();
@@ -239,6 +247,10 @@ void WFXMLScanner::scanDocument(const InputSource& src)
                     , excToCatch.getMessage()
                 );
         }
+        catch(const OutOfMemoryException&)
+        {
+            throw;
+        }
         catch(...)
         {
             // Flush the reader manager and rethrow user's error
@@ -249,6 +261,10 @@ void WFXMLScanner::scanDocument(const InputSource& src)
         // If it returned, then reset the reader manager and fall through
         fReaderMgr.reset();
     }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch(...)
     {
         // Reset and rethrow
@@ -404,6 +420,10 @@ bool WFXMLScanner::scanNext(XMLPScanToken& token)
                     , excToCatch.getMessage()
                 );
         }
+        catch(const OutOfMemoryException&)
+        {
+            throw;
+        }
         catch(...)
         {
             // Reset and rethrow user error
@@ -415,6 +435,10 @@ bool WFXMLScanner::scanNext(XMLPScanToken& token)
         fReaderMgr.reset();
         return false;
     }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch(...)
     {
         // Reset and rethrow original error
@@ -814,9 +838,9 @@ bool WFXMLScanner::scanStartTag(bool& gotData)
             elemDecl = fElements->elementAt(fElementIndex);
         }
         else {
-            elemDecl = new (fMemoryManager) DTDElementDecl
+            elemDecl = new (fGrammarPoolMemoryManager) DTDElementDecl
             (
-                fMemoryManager
+                fGrammarPoolMemoryManager
             );
             fElements->addElement(elemDecl);
         }
@@ -1141,9 +1165,9 @@ bool WFXMLScanner::scanStartTagNS(bool& gotData)
             elemDecl = fElements->elementAt(fElementIndex);
         }
         else {
-            elemDecl = new (fMemoryManager) DTDElementDecl
+            elemDecl = new (fGrammarPoolMemoryManager) DTDElementDecl
             (
-                fMemoryManager
+                fGrammarPoolMemoryManager
             );
             fElements->addElement(elemDecl);
         }
@@ -1409,6 +1433,23 @@ bool WFXMLScanner::scanStartTagNS(bool& gotData)
                 }
             }
 
+            // check for duplicate namespace attributes:
+            // by checking for qualified names with the same local part and with prefixes 
+            // which have been bound to namespace names that are identical. 
+            XMLAttr* loopAttr;
+            for (unsigned int attrIndex=0; attrIndex < attCount; attrIndex++) {
+                loopAttr = fAttrList->elementAt(attrIndex);
+                if (curAtt->getURIId() == loopAttr->getURIId() &&
+                    XMLString::equals(curAtt->getName(), loopAttr->getName())) {
+                    emitError
+                    ( 
+                        XMLErrs::AttrAlreadyUsedInSTag
+                        , curAtt->getName()
+                        , elemDecl->getFullName()
+                    );
+                }
+            }  
+
             // increment attribute count
             attCount++;
 
@@ -1604,7 +1645,6 @@ bool WFXMLScanner::scanAttValue(const XMLCh* const attrName
     //  handler on every round.
     XMLCh   nextCh;
     XMLCh   secondCh = 0;
-    bool    firstNonWS = false;
     bool    gotLeadingSurrogate = false;
     bool    escaped;
     while (true)
@@ -1725,14 +1765,6 @@ bool WFXMLScanner::scanAttValue(const XMLCh* const attrName
 //  this call.
 void WFXMLScanner::scanCDSection()
 {
-    //  This is the CDATA section opening sequence, minus the '<' character.
-    //  We use this to watch for nested CDATA sections, which are illegal.
-    static const XMLCh CDataPrefix[] =
-    {
-            chBang, chOpenSquare, chLatin_C, chLatin_D, chLatin_A
-        ,   chLatin_T, chLatin_A, chOpenSquare, chNull
-    };
-
     static const XMLCh CDataClose[] =
     {
             chCloseSquare, chCloseAngle, chNull
