@@ -55,7 +55,7 @@
  */
 
 /*
- * $Id: DOMBuilderImpl.hpp,v 1.13 2003/05/15 18:26:50 knoaman Exp $
+ * $Id: DOMBuilderImpl.hpp,v 1.15 2003/10/30 21:37:31 knoaman Exp $
  *
  */
 
@@ -70,6 +70,9 @@
 
 XERCES_CPP_NAMESPACE_BEGIN
 
+class XMLEntityResolver;
+class XMLResourceIdentifier;
+
  /**
   * Introduced in DOM Level 3
   *
@@ -93,13 +96,18 @@ public :
       * validation. If you don't provide a validator, a default one will
       * be created for you in the scanner.
       *
+      * @param gramPool   Pointer to the grammar pool instance from 
+      *                   external application.
+      *                   The parser does NOT own it.
+      *
       * @param valToAdopt Pointer to the validator instance to use. The
       *                   parser is responsible for freeing the memory.
       */
     DOMBuilderImpl
     (
-          XMLValidator* const  valToAdopt = 0
-        , MemoryManager* const manager = XMLPlatformUtils::fgMemoryManager
+          XMLValidator* const   valToAdopt = 0
+        , MemoryManager* const  manager = XMLPlatformUtils::fgMemoryManager
+        , XMLGrammarPool* const gramPool = 0        
     );
 
     /**
@@ -155,6 +163,26 @@ public :
       */
     DOMEntityResolver* getEntityResolver();
 
+    /**
+      * Get a pointer to the entity resolver
+      *
+      * This method returns the installed entity resolver.  If no resolver
+      * has been installed, then it will be a zero pointer.
+      *
+      * @return The pointer to the installed entity resolver object.
+      */
+    XMLEntityResolver* getXMLEntityResolver();
+ 
+    /**
+      * Get a const pointer to the entity resolver
+      *
+      * This method returns the installed entity resolver. If no resolver
+      * has been installed, then it will be a zero pointer.
+      *
+      * @return A const pointer to the installed entity resolver object.
+      */
+    const XMLEntityResolver* getXMLEntityResolver() const;
+
     /**
       * <p><b>"Experimental - subject to change"</b></p>
       *
@@ -229,8 +257,9 @@ public :
       * can trap and potentially redirect references to external
       * entities.
       *
-      * <i>Any previously set resolver is merely dropped, since the parser
-      * does not own them.</i>
+      * <i>Any previously set entity resolver is merely dropped, since the parser
+      * does not own them.  If both setEntityResolver and setXMLEntityResolver
+      * are called, then the last one is used.</i>
       *
       * @param handler  A const pointer to the user supplied entity
       *                 resolver.
@@ -239,6 +268,25 @@ public :
       */
     void setEntityResolver(DOMEntityResolver* const handler);
 
+    /**
+      * Set the entity resolver
+      *
+      * This method allows applications to install their own entity
+      * resolver. By installing an entity resolver, the applications
+      * can trap and potentially redirect references to external
+      * entities.
+      *
+      * <i>Any previously set entity resolver is merely dropped, since the parser
+      * does not own them.  If both setEntityResolver and setXMLEntityResolver
+      * are called, then the last one is used.</i>
+      *
+      * @param handler  A const pointer to the user supplied entity
+      *                 resolver.
+      *
+      * @see #getXMLEntityResolver
+      */
+    void setXMLEntityResolver(XMLEntityResolver* const handler);
+
     /**
       * <p><b>"Experimental - subject to change"</b></p>
       *
@@ -765,6 +813,8 @@ public :
       * implement 'redirection' via this callback. This method is also
       * borrowed from the SAX specification.
       *
+      * @deprecated This method is no longer called (the other resolveEntity one is).
+      *
       * @param publicId A const pointer to a Unicode string representing the
       *                 public id of the entity just parsed.
       * @param systemId A const pointer to a Unicode string representing the
@@ -786,6 +836,27 @@ public :
         , const XMLCh* const    baseURI = 0
     );
 
+    /** Resolve a public/system id
+      *
+      * This method allows a user installed entity handler to further
+      * process any pointers to external entities. The applications can
+      * implement 'redirection' via this callback.  
+      *
+      * @param resourceIdentifier An object containing the type of
+      *        resource to be resolved and the associated data members
+      *        corresponding to this type.
+      * @return The value returned by the user installed resolveEntity
+      *         method or NULL otherwise to indicate no processing was done.
+      *         The returned InputSource is owned by the parser which is
+      *         responsible to clean up the memory.
+      * @see XMLEntityHandler
+      * @see XMLEntityResolver
+      */
+    virtual InputSource* resolveEntity
+    (
+        XMLResourceIdentifier* resourceIdentifier
+    );
+
     /** Handle a 'start input source' event
       *
       * This method is used to indicate the start of parsing an external
@@ -827,6 +898,7 @@ private :
     bool                        fAutoValidation;
     bool                        fValidation;
     DOMEntityResolver*          fEntityResolver;
+    XMLEntityResolver*          fXMLEntityResolver;
     DOMErrorHandler*            fErrorHandler;
     DOMBuilderFilter*           fFilter;
     bool                        fCharsetOverridesXMLEncoding;
@@ -883,6 +955,16 @@ inline const DOMEntityResolver* DOMBuilderImpl::getEntityResolver() const
     return fEntityResolver;
 }
 
+inline XMLEntityResolver* DOMBuilderImpl::getXMLEntityResolver()
+{
+    return fXMLEntityResolver;
+}
+
+inline const XMLEntityResolver* DOMBuilderImpl::getXMLEntityResolver() const
+{
+    return fXMLEntityResolver;
+}
+
 inline DOMBuilderFilter* DOMBuilderImpl::getFilter()
 {
     return fFilter;
