@@ -55,7 +55,7 @@
  */
 
 /*
- * $Id: Tru64PlatformUtils.cpp,v 1.10 2003/05/15 18:37:49 knoaman Exp $
+ * $Id: Tru64PlatformUtils.cpp,v 1.11 2003/10/01 16:32:40 neilg Exp $
  */
 
 // ---------------------------------------------------------------------------
@@ -79,6 +79,7 @@
 #include    <xercesc/util/XMLUni.hpp>
 #include    <xercesc/util/XMLUniDefs.hpp>
 #include    <xercesc/util/PanicHandler.hpp>
+#include    <xercesc/util/OutOfMemoryException.hpp>
 
 //
 //  These control which transcoding service is used by the Tru64 version.
@@ -152,6 +153,10 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     retVal = new InMemMsgLoader(msgDomain);
 #endif
   }
+  catch(const OutOfMemoryException&)
+  {
+    throw;
+  }
   catch(...)
   {
     panic(PanicHandler::Panic_CantLoadMsgDomain);
