@@ -55,7 +55,7 @@
  */
 
 /*
- * $Id: ICUTransService.cpp,v 1.9 2003/05/17 16:32:17 knoaman Exp $
+ * $Id: ICUTransService.cpp,v 1.11 2003/08/31 18:10:08 neilg Exp $
  */
 
 
@@ -127,11 +127,11 @@ static UChar* convertToUChar( const   XMLCh* const    toConvert
 
 
 static XMLCh* convertToXMLCh( const UChar* const toConvert,
-                            , MemoryManager* const manager = 0)
+                            MemoryManager* const manager = 0)
 {
     const unsigned int srcLen = u_strlen(toConvert);
     XMLCh* retBuf = (manager)
-        ? (XMLCh*) manager->allocate((srcLen+1) sizeof(XMLCh))
+        ? (XMLCh*) manager->allocate((srcLen+1) * sizeof(XMLCh))
         : new XMLCh[srcLen + 1];
 
     XMLCh* outPtr = retBuf;
@@ -907,7 +907,7 @@ char* ICULCPTranscoder::transcode(const XMLCh* const toTranscode)
     }
 
     // If targetLen is not enough then buffer overflow might occur
-    if (err == U_BUFFER_OVERFLOW_ERROR)
+    if ((err == U_BUFFER_OVERFLOW_ERROR) || (err == U_STRING_NOT_TERMINATED_WARNING))
     {
         //
         //  Reset the error, delete the old buffer, allocate a new one,
@@ -936,8 +936,6 @@ char* ICULCPTranscoder::transcode(const XMLCh* const toTranscode)
         return 0;
     }
 
-    // Cap it off and return
-    retBuf[targetCap] = 0;
     return retBuf;
 }
 
@@ -1010,7 +1008,7 @@ char* ICULCPTranscoder::transcode(const XMLCh* const toTranscode,
     }
 
     // If targetLen is not enough then buffer overflow might occur
-    if (err == U_BUFFER_OVERFLOW_ERROR)
+    if ((err == U_BUFFER_OVERFLOW_ERROR) || (err == U_STRING_NOT_TERMINATED_WARNING))
     {
         //
         //  Reset the error, delete the old buffer, allocate a new one,
@@ -1039,8 +1037,6 @@ char* ICULCPTranscoder::transcode(const XMLCh* const toTranscode,
         return 0;
     }
 
-    // Cap it off and return
-    retBuf[targetCap] = 0;
     return retBuf;
 }
 
