@@ -55,16 +55,18 @@
  */
 
 /*
- * $Id: Iconv390TransService.cpp,v 1.2 2002/04/09 15:44:00 knoaman Exp $
+ * $Id: Iconv390TransService.cpp,v 1.7 2003/05/17 16:32:17 knoaman Exp $
  */
 
 
 // ---------------------------------------------------------------------------
 //  Includes
 // ---------------------------------------------------------------------------
+#include "Iconv390TransService.hpp"
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLUni.hpp>
-#include "Iconv390TransService.hpp"
+#include <xercesc/util/regx/XMLUniCharacter.hpp>
+#include <xercesc/framework/MemoryManager.hpp>
 
 #include <wchar.h>
 #include <string.h>
@@ -75,6 +77,9 @@
 #include <unistd.h>
 #endif
 #include <ctype.h>
+
+XERCES_CPP_NAMESPACE_BEGIN
+
 //
 //  Cannot use the OS/390 c/c++ towupper and towlower functions in the
 //  Unicode environment. We will use mytowupper and mytowlower here.
@@ -277,7 +282,13 @@ const XMLCh* Iconv390TransService::getId() const
 
 bool Iconv390TransService::isSpace(const XMLCh toCheck) const
 {
-    return (iswspace(toCheck) != 0);
+   unsigned short chartype = XMLUniCharacter::getType(toCheck);
+   if ( (chartype == XMLUniCharacter::SPACE_SEPARATOR) ||
+        (chartype == XMLUniCharacter::LINE_SEPARATOR)   ||
+        (chartype == XMLUniCharacter::PARAGRAPH_SEPARATOR) )
+      return true;
+   else
+      return false;
 }
 
 
@@ -306,22 +317,16 @@ bool Iconv390TransService::supportsSrcOfs() const
 XMLTranscoder*
 Iconv390TransService::makeNewXMLTranscoder(const   XMLCh* const            encodingName
                                         ,       XMLTransService::Codes& resValue
-                                        , const unsigned int            )
+                                        , const unsigned int
+                                        ,       MemoryManager* const)
 {
+    //  This is a minimalist transcoding service, that only supports a local
+    //  default transcoder. All named encodings return zero as a failure,
+    //  which means that only the intrinsic encodings supported by the parser
+    //  itself will work for XML data.
     //
-    //  Translate the input encodingName from Unicode XMLCh format into
-    //  ibm-037 char format via the lookup table.
-    //
-    char charEncodingName[256];
-    const XMLCh*  srcPtr = encodingName;
-    char*         outPtr = charEncodingName;
-    while (*srcPtr != 0)
-        *outPtr++ = toupper(gUnicodeToIBM037XlatTable[*srcPtr++]);
-    *outPtr=0;
-
-    iconvconverter *tconv=addConverter(charEncodingName,resValue);
-
-    return new Iconv390Transcoder(tconv, encodingName, 0);
+    resValue = XMLTransService::UnsupportedEncoding;
+    return 0;
 }
 
 void Iconv390TransService::upperCase(XMLCh* const toUpperCase) const
@@ -347,33 +352,18 @@ void Iconv390TransService::lowerCase(XMLCh* const toLowerCase) const
 // ---------------------------------------------------------------------------
 unsigned int Iconv390LCPTranscoder::calcRequiredSize(const char* const srcText)
 {
-    unsigned int retVal;
-
     if (!srcText)
         return 0;
 
-#ifdef OS390BATCH
-    //
-    // Cannot use mbstowcs in a non-POSIX environment(???).
-    //
-    if (!__isPosixOn()) {
-        const unsigned charLen = mblen(srcText, MB_CUR_MAX);
-        if (charLen == -1)
-            return 0;
-        else {
-            if (charLen != 0)
-                retVal = strlen(srcText)/charLen;
-            else
-                retVal = charLen;
-        }
-    }
-    else
-#endif
-        retVal = ::mbstowcs(NULL, srcText, 0);
-
-    if (retVal == -1)
+    unsigned charLen = ::mblen(srcText, MB_CUR_MAX);
+    if (charLen == -1)
         return 0;
-    return retVal;
+    else if (charLen != 0)
+        charLen = strlen(srcText)/charLen;
+
+    if (charLen == -1)
+        return 0;
+    return charLen;
 }
 
 
@@ -388,7 +378,10 @@ unsigned int Iconv390LCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
     wchar_t*      wideCharBuf = 0;
 
     if (wLent >= gTempBuffArraySize)
-        wideCharBuf = allocatedArray = new wchar_t[wLent + 1];
+        wideCharBuf = allocatedArray = (wchar_t*) XMLPlatformUtils::fgMemoryManager->allocate
+        (
+            (wLent + 1) * sizeof(wLent + 1)
+        );//new wchar_t[wLent + 1];
     else
         wideCharBuf = tmpWideCharArr;
 
@@ -399,7 +392,7 @@ unsigned int Iconv390LCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
     wideCharBuf[wLent] = 0x00;
 
     const unsigned int retVal = ::wcstombs(NULL, wideCharBuf, 0);
-    delete [] allocatedArray;
+    XMLPlatformUtils::fgMemoryManager->deallocate(allocatedArray);//delete [] allocatedArray;
 
     if (retVal == -1)
         return 0;
@@ -437,6 +430,36 @@ char* Iconv390LCPTranscoder::transcode(const XMLCh* const toTranscode)
     return retVal;
 }
 
+char* Iconv390LCPTranscoder::transcode(const XMLCh* const toTranscode,
+                                       MemoryManager* const manager)
+{
+    if (!toTranscode)
+        return 0;
+
+    char* retVal = 0;
+    if (*toTranscode)
+    {
+        unsigned int  wLent = getWideCharLength(toTranscode);
+	//
+	//  Translate the input from Unicode XMLCh format into
+	//  ibm-037 char format via the lookup table.
+	//
+        retVal = (char*) manager->allocate((wLent + 1) * sizeof(char));//new char[wLent + 1];
+        const XMLCh *srcPtr = toTranscode;
+        char *outPtr = retVal;
+
+	while (*srcPtr != 0)
+	    *outPtr++ = gUnicodeToIBM037XlatTable[*srcPtr++];
+	*outPtr=0;
+    }
+    else
+    {
+        retVal = (char*) manager->allocate(sizeof(char));//new char[1];
+        retVal[0] = 0;
+    }
+    return retVal;
+}
+
 
 bool Iconv390LCPTranscoder::transcode( const   XMLCh* const    toTranscode
                                     ,       char* const     toFill
@@ -515,6 +538,53 @@ XMLCh* Iconv390LCPTranscoder::transcode(const char* const toTranscode)
     return retVal;
 }
 
+XMLCh* Iconv390LCPTranscoder::transcode(const char* const toTranscode,
+                                        MemoryManager* const manager)
+{
+    if (!toTranscode)
+        return 0;
+
+    XMLCh* retVal = 0;
+    if (*toTranscode)
+    {
+        const unsigned int len = calcRequiredSize(toTranscode);
+        if (len == 0)
+        {
+            retVal = (XMLCh*) manager->allocate(sizeof(XMLCh));//new XMLCh[1];
+            retVal[0] = 0;
+            return retVal;
+        }
+
+        wchar_t       tmpWideCharArr[gTempBuffArraySize];
+        wchar_t*      allocatedArray = 0;
+        wchar_t*      wideCharBuf = 0;
+
+        retVal = (XMLCh*) manager->allocate((len + 1) * sizeof(XMLCh));//new XMLCh[len + 1];
+
+        size_t retCode;
+        char *tmpInPtr = (char*) toTranscode;
+        char *tmpOutPtr = (char*) retVal;
+        size_t inByteLeft = len;
+        size_t outByteLeft = len*2;
+        {
+         XMLMutexLock lockConverter(&converter->fMutex);
+         retCode = iconv(converter->fIconv390Descriptor, &tmpInPtr, &inByteLeft, &tmpOutPtr, &outByteLeft);
+        }
+        if (retCode == -1) {
+            manager->deallocate(retVal);//delete [] retVal;
+            return 0;
+        }
+        retVal[len] = 0x00;
+        manager->deallocate(allocatedArray);//delete [] allocatedArray;
+    }
+    else
+    {
+        retVal = (XMLCh*) manager->allocate(sizeof(XMLCh));//new XMLCh[1];
+        retVal[0] = 0;
+    }
+    return retVal;
+}
+
 
 bool Iconv390LCPTranscoder::transcode( const   char* const     toTranscode
                                     ,       XMLCh* const    toFill
@@ -569,96 +639,4 @@ Iconv390LCPTranscoder::~Iconv390LCPTranscoder()
     converter=0;
 }
 
-// ---------------------------------------------------------------------------
-//  Iconv390Transcoder: Constructors and Destructor
-// ---------------------------------------------------------------------------
-Iconv390Transcoder::Iconv390Transcoder(const  XMLCh* const    encodingName
-                                , const unsigned int    blockSize) :
-    XMLTranscoder(encodingName, blockSize)
-{
-}
-
-Iconv390Transcoder::Iconv390Transcoder(iconvconverter_t* const toAdopt
-				,const XMLCh* const encodingName
-				,const unsigned int blockSize) :
- 	XMLTranscoder(encodingName, blockSize)
-       ,converter (toAdopt)
-{
-}
-
-Iconv390Transcoder::~Iconv390Transcoder()
-{
-    removeConverter(converter);
-    converter=0;
-}
-
-
-// ---------------------------------------------------------------------------
-//  Iconv390Transcoder: Implementation of the virtual transcoder API
-// ---------------------------------------------------------------------------
-XMLCh Iconv390Transcoder::transcodeOne(const   XMLByte* const     srcData
-                                    , const unsigned int    srcBytes
-                                    ,       unsigned int&   bytesEaten)
-{
-    wchar_t  toFill;
-
-    size_t retCode;
-    char *tmpInPtr = (char*) srcData;
-    char *tmpOutPtr = (char*)&toFill;
-    size_t inByteLeft = srcBytes;
-    size_t outByteLeft = 2;
-    {
-     XMLMutexLock lockConverter(&converter->fMutex);
-     retCode = iconv(converter->fIconv390Descriptor, &tmpInPtr, &inByteLeft, &tmpOutPtr, &outByteLeft);
-    }
-    if (retCode == -1) {
-        bytesEaten = 0;
-        return 0;
-    }
-    int eaten = srcBytes-inByteLeft;
-    if (eaten == -1)
-    {
-        bytesEaten = 0;
-        return 0;
-    }
-
-    // Return the bytes we ate and the resulting char.
-    bytesEaten = eaten;
-    return toFill;
-}
-
-
-unsigned int
-Iconv390Transcoder::transcodeXML(  const   XMLByte* const             srcData
-                                , const unsigned int            srcCount
-                                ,       XMLCh* const            toFill
-                                , const unsigned int            maxChars
-                                ,       unsigned int&           bytesEaten
-								,       unsigned char* const    charSizes)
-{
-    //
-    //  For this one, because we have to maintain the offset table, we have
-    //  to do them one char at a time until we run out of source data.
-    //
-    unsigned int countIn = 0;
-    unsigned int countOut = 0;
-
-    size_t retCode;
-    char *tmpInPtr = (char *) srcData;
-    char *tmpOutPtr = (char *) toFill;
-    size_t inByteLeft = srcCount;
-    size_t outByteLeft = maxChars*2;
-    {
-     XMLMutexLock lockConverter(&converter->fMutex);
-     retCode = iconv(converter->fIconv390Descriptor, &tmpInPtr, &inByteLeft, &tmpOutPtr, &outByteLeft);
-    }
-    if (retCode == -1)
-    {
-	return 0;
-    }
-
-    // Give back the counts of eaten and transcoded
-    bytesEaten = srcCount-inByteLeft;
-    return maxChars-outByteLeft/2;
-
-}
+XERCES_CPP_NAMESPACE_END
