@@ -55,8 +55,15 @@
  */
 
 /*
- * $Id: XMLFloat.cpp,v 1.11 2003/05/16 06:01:53 knoaman Exp $
+ * $Id: XMLFloat.cpp,v 1.13 2003/10/15 14:50:01 peiyongz Exp $
  * $Log: XMLFloat.cpp,v $
+ * Revision 1.13  2003/10/15 14:50:01  peiyongz
+ * Bugzilla#22821: locale-sensitive function used to validate 'double' type, patch
+ * from jsweeney@spss.com (Jeff Sweeney)
+ *
+ * Revision 1.12  2003/09/23 18:16:07  peiyongz
+ * Inplementation for Serialization/Deserialization
+ *
  * Revision 1.11  2003/05/16 06:01:53  knoaman
  * Partial implementation of the configurable memory manager.
  *
@@ -163,6 +170,9 @@ XMLFloat::~XMLFloat()
 void XMLFloat::checkBoundary(const XMLCh* const strValue)
 {
     char *nptr = XMLString::transcode(strValue, getMemoryManager());
+
+    normalizeDecimalPoint(nptr);
+
     ArrayJanitor<char> jan1(nptr, getMemoryManager());
     int   strLen = strlen(nptr);
     char *endptr = 0;
@@ -237,4 +247,20 @@ void XMLFloat::checkBoundary(const XMLCh* const strValue)
     }
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(XMLFloat)
+
+XMLFloat::XMLFloat(MemoryManager* const manager)
+:XMLAbstractDoubleFloat(manager)
+{
+}
+
+void XMLFloat::serialize(XSerializeEngine& serEng)
+{
+    XMLAbstractDoubleFloat::serialize(serEng);
+}
+
 XERCES_CPP_NAMESPACE_END
