@@ -55,7 +55,7 @@
  */
 
 /*
- * $Id: XMLString.cpp,v 1.23 2003/05/18 14:02:05 knoaman Exp $
+ * $Id: XMLString.cpp,v 1.27 2003/11/03 15:35:52 amassari Exp $
  */
 
 
@@ -491,6 +491,19 @@ unsigned int XMLString::replaceTokens(          XMLCh* const    errText
 }
 
 
+XMLCh* XMLString::replicate(const XMLCh* const toRep)
+{
+    // If a null string, return a null string!
+    XMLCh* ret = 0;
+    if (toRep)
+    {
+        const unsigned int len = stringLen(toRep);
+        ret = new XMLCh[len + 1];
+        memcpy(ret, toRep, (len + 1) * sizeof(XMLCh));
+    }
+    return ret;
+}
+
 char* XMLString::replicate(const char* const toRep)
 {
     // If a null string, return a null string
@@ -1209,11 +1222,11 @@ int XMLString::indexOf( const   XMLCh* const    toSearch
     return -1;
 }
 
-
-int XMLString::lastIndexOf(const XMLCh* const toSearch, const XMLCh ch)
+int XMLString::lastIndexOf(const XMLCh ch,
+                           const XMLCh* const toSearch,
+                           const unsigned int toSearchLen)
 {
-    const int len = stringLen(toSearch);
-    for (int i = len-1; i >= 0; i--)
+    for (int i = (int)toSearchLen-1; i >= 0; i--)
     {
         if (toSearch[i] == ch)
             return i;
@@ -1739,7 +1752,6 @@ void XMLString::fixURI(const XMLCh* const str, XMLCh* const target)
         return;
 
     int colonIdx = XMLString::indexOf(str, chColon);
-    int slashIdx = XMLString::indexOf(str, chForwardSlash);
 
     // If starts with a '/' we assume
     // this is an absolute (UNIX) file path and prefix it with file://
