@@ -55,7 +55,7 @@
  */
 
 /*
- * $Id: XMLUni.cpp,v 1.30 2003/04/17 21:58:50 neilg Exp $
+ * $Id: XMLUni.cpp,v 1.38 2003/11/25 03:46:26 neilg Exp $
  */
 
 
@@ -168,6 +168,17 @@ const XMLCh XMLUni::fgIBM037EncodingString2[] =
     chLatin_I, chLatin_B, chLatin_M, chDigit_0, chDigit_3, chDigit_7, chNull
 };
 
+//hhe
+const XMLCh XMLUni::fgIBM1047EncodingString[] =
+{
+    chLatin_I, chLatin_B, chLatin_M, chDigit_1, chDigit_0, chDigit_4, chDigit_7, chNull
+};
+
+const XMLCh XMLUni::fgIBM1047EncodingString2[] =
+{
+    chLatin_I, chLatin_B, chLatin_M, chDash, chDigit_1, chDigit_0, chDigit_4, chDigit_7, chNull
+};
+
 const XMLCh XMLUni::fgIBM1140EncodingString[] =
 {
     chLatin_I, chLatin_B, chLatin_M, chDigit_1, chDigit_1, chDigit_4, chDigit_0, chNull
@@ -702,6 +713,17 @@ const XMLCh XMLUni::fgDGXMLScanner[] =
     ,   chLatin_c, chLatin_a, chLatin_n, chLatin_n, chLatin_e, chLatin_r, chNull
 };
 
+const XMLCh XMLUni::fgCDataStart[] =
+{
+        chOpenAngle, chBang, chOpenSquare, chLatin_C, chLatin_D
+    ,   chLatin_A, chLatin_T, chLatin_A, chOpenSquare, chNull
+};
+
+const XMLCh XMLUni::fgCDataEnd[] =
+{
+         chCloseSquare, chCloseSquare, chCloseAngle, chNull
+};
+
 //Exception strings
 const XMLCh XMLUni::fgArrayIndexOutOfBoundsException_Name[] =
 {
@@ -746,10 +768,10 @@ const XMLCh XMLUni::fgIOException_Name[] =
 
 const XMLCh XMLUni::fgNoSuchElementException_Name[] =
 {
-        chLatin_N, chLatin_o, chLatin_S, chLatin_u, chLatin_h, chLatin_h
-    ,   chLatin_E, chLatin_l, chLatin_e, chLatin_e, chLatin_m, chLatin_e
-    ,   chLatin_n, chLatin_t, chLatin_E, chLatin_x, chLatin_c, chLatin_e
-    ,   chLatin_p, chLatin_t, chLatin_i, chLatin_o, chLatin_n, chNull
+        chLatin_N, chLatin_o, chLatin_S, chLatin_u, chLatin_c, chLatin_h
+    ,   chLatin_E, chLatin_l, chLatin_e, chLatin_m, chLatin_e, chLatin_n
+    ,   chLatin_t, chLatin_E, chLatin_x, chLatin_c, chLatin_e, chLatin_p
+    ,   chLatin_t, chLatin_i, chLatin_o, chLatin_n, chNull
 };
 
 const XMLCh XMLUni::fgNullPointerException_Name[] =
@@ -876,6 +898,14 @@ const XMLCh XMLUni::fgXPathException_Name[] =
     ,   chLatin_o, chLatin_n, chNull
 };
 
+const XMLCh XMLUni::fgXSerializationException_Name[] =
+{
+        chLatin_X, chLatin_S, chLatin_e, chLatin_r, chLatin_i, chLatin_a
+    ,   chLatin_l, chLatin_i, chLatin_z, chLatin_a, chLatin_t, chLatin_i
+    ,   chLatin_o, chLatin_n, chLatin_E, chLatin_x, chLatin_c, chLatin_e
+    ,   chLatin_p, chLatin_t, chLatin_i, chLatin_o, chLatin_n, chNull
+};
+
 const XMLCh XMLUni::fgNegINFString[] =
 {
     chDash, chLatin_I, chLatin_N, chLatin_F, chNull
@@ -1129,6 +1159,23 @@ const XMLCh XMLUni::fgXercesScannerName[] =
     ,   chLatin_m, chLatin_e, chNull
 };
 
+//Property
+//Xerces: http://apache.org/xml/properties/parser-use-DOMDocument-from-Implementation
+const XMLCh XMLUni::fgXercesParserUseDocumentFromImplementation[] =
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_p, chLatin_a
+    ,   chLatin_r, chLatin_s, chLatin_e, chLatin_r, chDash, chLatin_u, chLatin_s
+    ,   chLatin_e, chDash, chLatin_D, chLatin_O, chLatin_M, chLatin_D, chLatin_o
+    ,   chLatin_c, chLatin_u, chLatin_m, chLatin_e, chLatin_n, chLatin_t, chDash
+    ,   chLatin_f, chLatin_r, chLatin_o, chLatin_m, chDash, chLatin_I, chLatin_m
+    ,   chLatin_p, chLatin_l, chLatin_e, chLatin_m, chLatin_e, chLatin_n, chLatin_t
+    ,   chLatin_a, chLatin_t, chLatin_i, chLatin_o, chLatin_n, chNull
+};
+
+
 //Xerces: http://apache.org/xml/features/dom/user-adopts-DOMDocument
 const XMLCh XMLUni::fgXercesUserAdoptsDOMDocument[] =
 {
@@ -1352,6 +1399,14 @@ const XMLCh XMLUni::fgDOMWRTBOM[] =
     chLatin_m, chLatin_a, chLatin_r, chLatin_k, chNull
 };
 
+//xml-declaration
+const XMLCh XMLUni::fgDOMXMLDeclaration[] =
+{ 
+    chLatin_x, chLatin_m, chLatin_l, chDash, chLatin_d, chLatin_e, chLatin_c,
+    chLatin_l, chLatin_a, chLatin_r, chLatin_a, chLatin_t, chLatin_i, chLatin_o,
+    chLatin_n, chNull 
+};
+
 // en_US
 const char XMLUni::fgXercescDefaultLocale[] = "en_US";
 
