@@ -55,8 +55,20 @@
  */
 
 /*
- * $Id: AbstractNumericFacetValidator.cpp,v 1.12 2003/05/15 18:53:26 knoaman Exp $
+ * $Id: AbstractNumericFacetValidator.cpp,v 1.16 2003/11/12 20:32:03 peiyongz Exp $
  * $Log: AbstractNumericFacetValidator.cpp,v $
+ * Revision 1.16  2003/11/12 20:32:03  peiyongz
+ * Statless Grammar: ValidationContext
+ *
+ * Revision 1.15  2003/10/17 21:13:43  peiyongz
+ * using XTemplateSerializer
+ *
+ * Revision 1.14  2003/10/07 19:39:37  peiyongz
+ * Use of Template_Class Object Serialization/Deserialization API
+ *
+ * Revision 1.13  2003/10/02 19:21:06  peiyongz
+ * Implementation of Serialization/Deserialization
+ *
  * Revision 1.12  2003/05/15 18:53:26  knoaman
  * Partial implementation of the configurable memory manager.
  *
@@ -121,6 +133,15 @@
 #include <xercesc/validators/datatype/InvalidDatatypeFacetException.hpp>
 #include <xercesc/util/NumberFormatException.hpp>
 
+//since we need to dynamically created each and every derivatives 
+//during deserialization by XSerializeEngine>>Derivative, we got
+//to include all hpp
+#include <xercesc/util/XMLFloat.hpp>
+#include <xercesc/util/XMLDouble.hpp>
+#include <xercesc/util/XMLBigDecimal.hpp>
+#include <xercesc/util/XMLDateTime.hpp>
+#include <xercesc/internal/XTemplateSerializer.hpp>
+
 XERCES_CPP_NAMESPACE_BEGIN
 
 const int AbstractNumericFacetValidator::INDETERMINATE = 2;
@@ -136,7 +157,7 @@ const int AbstractNumericFacetValidator::INDETERMINATE = 2;
 {                                                             \
     try                                                       \
 {                                                             \
-        numBase->checkContent(val->getRawData(), false);      \
+        numBase->checkContent(val->getRawData(), (ValidationContext*)0, false);      \
 }                                                             \
     catch ( XMLException& )                                   \
 {                                                             \
@@ -856,6 +877,90 @@ const RefArrayVectorOf<XMLCh>* AbstractNumericFacetValidator::getEnumString() co
 	return (fEnumerationInherited? getBaseValidator()->getEnumString() : fStrEnumeration );
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_NOCREATE(AbstractNumericFacetValidator)
+
+/***
+ *  This dv needs to serialize/deserialize four boundary data members
+ *  which are derivatives of XMLlNumber.
+ *  The derivatives of this class, namely, Deciamldv, Doubledv, Floatdv and
+ *  DateTimedv needs to write a typeEnum into the binary data stream, so
+ *  during loading, this method reads the typeEnum first, and then instantiate
+ *  the right type of objects, say XMLDouble, XMLFloat, XMLBigDecimal and 
+ *  XMLDateTime.
+ *
+ *  
+ ***/
+void AbstractNumericFacetValidator::serialize(XSerializeEngine& serEng)
+{
+
+    if (serEng.isStoring())
+    {
+
+        /***
+         * don't move this line out of the if statement,
+         * it is done purposely to allow AbstractNumericFacetValidator
+         * read the number type information before DatatypeValidator
+         * during loading
+         ***/
+        DatatypeValidator::serialize(serEng);
+
+        serEng<<fMaxInclusiveInherited;
+        serEng<<fMaxExclusiveInherited;
+        serEng<<fMinInclusiveInherited;
+        serEng<<fMinExclusiveInherited;
+        serEng<<fEnumerationInherited;
+ 
+        // need not write type info for the XMLNumber since
+        // the derivative class has done that
+        serEng<<fMaxInclusive;
+        serEng<<fMaxExclusive;
+        serEng<<fMinInclusive;
+        serEng<<fMinExclusive;
+
+        /***
+         * Serialize RefArrayVectorOf<XMLCh>
+         * Serialize RefVectorOf<XMLNumber>
+         ***/
+        XTemplateSerializer::storeObject(fStrEnumeration, serEng);
+        XTemplateSerializer::storeObject(fEnumeration, serEng);
+   
+    }
+    else
+    {
+        // Read the number type info for the XMLNumber FIRST!!!
+        int                     nType;
+        XMLNumber::NumberType   numType;
+        serEng>>nType;
+        numType = (XMLNumber::NumberType) nType;
+
+        DatatypeValidator::serialize(serEng);
+
+        serEng>>fMaxInclusiveInherited;
+        serEng>>fMaxExclusiveInherited;
+        serEng>>fMinInclusiveInherited;
+        serEng>>fMinExclusiveInherited;
+        serEng>>fEnumerationInherited;
+
+        fMaxInclusive=XMLNumber::loadNumber(numType, serEng);
+        fMaxExclusive=XMLNumber::loadNumber(numType, serEng);
+        fMinInclusive=XMLNumber::loadNumber(numType, serEng);
+        fMinExclusive=XMLNumber::loadNumber(numType, serEng);
+
+        /***
+         *  Deserialize RefArrayVectorOf<XMLCh>         
+         *  Deserialize RefVectorOf<XMLNumber>   
+         ***/
+        XTemplateSerializer::loadObject(&fStrEnumeration, 8, true, serEng);
+        XTemplateSerializer::loadObject(&fEnumeration, 8, true, numType, serEng);
+
+    }
+
+}
+
 XERCES_CPP_NAMESPACE_END
 
 /**
