@@ -55,8 +55,20 @@
  */
 
 /*
- * $Id: ListDatatypeValidator.cpp,v 1.9 2003/05/16 06:01:57 knoaman Exp $
+ * $Id: ListDatatypeValidator.cpp,v 1.13 2003/11/28 18:53:07 peiyongz Exp $
  * $Log: ListDatatypeValidator.cpp,v $
+ * Revision 1.13  2003/11/28 18:53:07  peiyongz
+ * Support for getCanonicalRepresentation
+ *
+ * Revision 1.12  2003/11/12 20:32:03  peiyongz
+ * Statless Grammar: ValidationContext
+ *
+ * Revision 1.11  2003/10/01 16:32:41  neilg
+ * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
+ *
+ * Revision 1.10  2003/09/30 21:31:30  peiyongz
+ * Implementation of Serialization/Deserialization
+ *
  * Revision 1.9  2003/05/16 06:01:57  knoaman
  * Partial implementation of the configurable memory manager.
  *
@@ -119,6 +131,7 @@
 #include <xercesc/validators/datatype/ListDatatypeValidator.hpp>
 #include <xercesc/validators/datatype/InvalidDatatypeFacetException.hpp>
 #include <xercesc/validators/datatype/InvalidDatatypeValueException.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -200,37 +213,41 @@ int ListDatatypeValidator::compare(const XMLCh* const lValue
 
 }
 
-void ListDatatypeValidator::validate( const XMLCh* const content)
+void ListDatatypeValidator::validate( const XMLCh*             const content
+                                    ,       ValidationContext* const context)
 {
     setContent(content);
     BaseRefVectorOf<XMLCh>* tokenVector = XMLString::tokenizeString(content);
     Janitor<BaseRefVectorOf<XMLCh> > janName(tokenVector);
-    checkContent(tokenVector, content, false);
+    checkContent(tokenVector, content, context, false);
 }
 
-void ListDatatypeValidator::checkContent( const XMLCh* const content, bool asBase)
+void ListDatatypeValidator::checkContent( const XMLCh*             const content
+                                         ,      ValidationContext* const context
+                                         ,      bool                     asBase)
 {
     setContent(content);
     BaseRefVectorOf<XMLCh>* tokenVector = XMLString::tokenizeString(content);
     Janitor<BaseRefVectorOf<XMLCh> > janName(tokenVector);
-    checkContent(tokenVector, content, asBase);
+    checkContent(tokenVector, content, context, asBase);
 }
 
 //
 // here content is a list of items
 //
-void ListDatatypeValidator::checkContent( BaseRefVectorOf<XMLCh>* tokenVector
-                                        , const XMLCh* const content
-                                        , bool asBase)
+void ListDatatypeValidator::checkContent(       BaseRefVectorOf<XMLCh>*       tokenVector
+                                        , const XMLCh*                  const content
+                                        ,       ValidationContext*      const context
+                                        ,       bool                          asBase)
 {
     DatatypeValidator* bv = getBaseValidator();
 
     if (bv->getType() == DatatypeValidator::List)
-        ((ListDatatypeValidator*)bv)->checkContent(tokenVector, content, true);
+        ((ListDatatypeValidator*)bv)->checkContent(tokenVector, content, context, true);
     else
     {   // the ultimate itemType DTV
         for (unsigned int i = 0; i < tokenVector->size(); i++)
-            bv->validate(tokenVector->elementAt(i));
+            bv->validate(tokenVector->elementAt(i), context);
     }
 
     int thisFacetsDefined = getFacetsDefined();
@@ -428,7 +445,11 @@ void ListDatatypeValidator::inspectFacetBase()
                     try
                     {
                         for ( int j = 0; j < tokenNumber; j++)
-                            getBaseValidator()->validate(tempList->elementAt(j));
+                            getBaseValidator()->validate(tempList->elementAt(j), (ValidationContext*)0);
+                    }
+                    catch(const OutOfMemoryException&)
+                    {
+                        throw;
                     }
                     catch (...)
                     {
@@ -439,7 +460,7 @@ void ListDatatypeValidator::inspectFacetBase()
                     delete tempList;
 
                     // enum shall pass this->checkContent() as well.
-                    checkContent(getEnumeration()->elementAt(i), false);
+                    checkContent(getEnumeration()->elementAt(i), (ValidationContext*)0, false);
                 }
             }
 
@@ -468,6 +489,56 @@ void ListDatatypeValidator::inheritFacet()
 
 }
 
+/***
+ * 2.5.1.2 List datatypes   
+ *   
+ * The canonical-lexical-representation for the list datatype is defined as 
+ * the lexical form in which each item in the list has the canonical 
+ * lexical representation of its itemType.
+ ***/
+const XMLCh* ListDatatypeValidator::getCanonicalRepresentation(const XMLCh*         const rawData
+                                                             ,       MemoryManager* const memMgr) const
+{
+    ListDatatypeValidator* temp = (ListDatatypeValidator*) this;
+
+    temp->setContent(rawData);
+    BaseRefVectorOf<XMLCh>* tokenVector = XMLString::tokenizeString(rawData);
+    Janitor<BaseRefVectorOf<XMLCh> > janName(tokenVector);
+    temp->checkContent(tokenVector, rawData, 0, false);
+
+    MemoryManager* toUse = memMgr? memMgr : getMemoryManager();
+    int  retBufSize = 2 * XMLString::stringLen(rawData);
+    XMLCh* retBuf = (XMLCh*) toUse->allocate(retBufSize * sizeof(XMLCh));
+    XMLCh* retBufPtr = retBuf;
+
+    DatatypeValidator* itemDv = this->getItemTypeDTV();
+    for (unsigned int i = 0; i < tokenVector->size(); i++)
+    {
+        XMLCh* itemCanRep = (XMLCh*) itemDv->getCanonicalRepresentation(tokenVector->elementAt(i), memMgr);
+        XMLString::catString(retBufPtr, itemCanRep);
+        retBufPtr = retBufPtr + XMLString::stringLen(itemCanRep) + 1;
+        *(retBufPtr++) = chSpace;
+        *(retBufPtr) = chNull;
+        toUse->deallocate(itemCanRep);
+    }
+
+    return 0;
+}
+
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(ListDatatypeValidator)
+
+void ListDatatypeValidator::serialize(XSerializeEngine& serEng)
+{
+    AbstractStringValidator::serialize(serEng);
+
+    //don't serialize fContent, since it is NOT owned and 
+    //will be reset each time validate()/checkContent() invoked.
+}
+
 XERCES_CPP_NAMESPACE_END
 
 /**
