@@ -55,8 +55,14 @@
  */
 
 /*
- * $Id: NOTATIONDatatypeValidator.cpp,v 1.5 2003/05/16 06:01:57 knoaman Exp $
+ * $Id: NOTATIONDatatypeValidator.cpp,v 1.7 2003/10/01 16:32:41 neilg Exp $
  * $Log: NOTATIONDatatypeValidator.cpp,v $
+ * Revision 1.7  2003/10/01 16:32:41  neilg
+ * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
+ *
+ * Revision 1.6  2003/09/30 21:31:30  peiyongz
+ * Implementation of Serialization/Deserialization
+ *
  * Revision 1.5  2003/05/16 06:01:57  knoaman
  * Partial implementation of the configurable memory manager.
  *
@@ -109,6 +115,7 @@
 #include <xercesc/util/XMLUri.hpp>
 #include <xercesc/validators/datatype/InvalidDatatypeFacetException.hpp>
 #include <xercesc/validators/datatype/InvalidDatatypeValueException.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -195,6 +202,10 @@ void NOTATIONDatatypeValidator::checkValueSpace(const XMLCh* const content)
             // no relative uri support here
             XMLUri  newURI(uriPart, fMemoryManager);
         }
+        catch(const OutOfMemoryException&)
+        {
+            throw;
+        }
         catch (...)
         {
             ThrowXML1(InvalidDatatypeValueException
@@ -225,6 +236,17 @@ int NOTATIONDatatypeValidator::getLength(const XMLCh* const content) const
     return XMLString::stringLen(content);
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(NOTATIONDatatypeValidator)
+
+void NOTATIONDatatypeValidator::serialize(XSerializeEngine& serEng)
+{
+    AbstractStringValidator::serialize(serEng);
+}
+
 XERCES_CPP_NAMESPACE_END
 
 /**
