@@ -56,6 +56,26 @@
 
 /*
  * $Log: SchemaElementDecl.hpp,v $
+ * Revision 1.17  2003/11/24 05:21:04  neilg
+ * update method documentation
+ *
+ * Revision 1.16  2003/11/21 22:34:46  neilg
+ * More schema component model implementation, thanks to David Cargill.
+ * In particular, this cleans up and completes the XSModel, XSNamespaceItem,
+ * XSAttributeDeclaration and XSAttributeGroup implementations.
+ *
+ * Revision 1.15  2003/11/06 15:30:08  neilg
+ * first part of PSVI/schema component model implementation, thanks to David Cargill.  This covers setting the PSVIHandler on parser objects, as well as implementing XSNotation, XSSimpleTypeDefinition, XSIDCDefinition, and most of XSWildcard, XSComplexTypeDefinition, XSElementDeclaration, XSAttributeDeclaration and XSAttributeUse.
+ *
+ * Revision 1.14  2003/10/14 15:22:28  peiyongz
+ * Implementation of Serialization/Deserialization
+ *
+ * Revision 1.13  2003/10/05 02:08:05  neilg
+ * Because it makes grammars un-sharable between parsers running on multiple threads, xsi:type should not be handled by modifying element declarations.  Modifying implementation so it no longer relies on this kind of behaviour; marking methods as deprecated which imply that xsi:type will be handled in this way.  Once their behaviour is handled elsewhere, these methods should eventually be removed
+ *
+ * Revision 1.12  2003/08/29 11:44:18  gareth
+ * If a type was explicitly declared as anyType that now gets set in DOMTypeInfo. Added test cases.
+ *
  * Revision 1.11  2003/05/18 14:02:08  knoaman
  * Memory manager implementation: pass per instance manager.
  *
@@ -225,6 +245,7 @@ public :
     virtual XMLAttDefList& getAttDefList() const;
     virtual CharDataOpts getCharDataOpts() const;
     virtual bool hasAttDefs() const;
+    // @deprecated; not thread-safe
     virtual bool resetDefs();
     virtual const ContentSpecNode* getContentSpec() const;
     virtual ContentSpecNode* getContentSpec();
@@ -273,10 +294,11 @@ public :
      *    1.1.1.2 clause 1.2 of Schema-Validity Assessment (Element) (3.3.4) applied and the item was valid as defined by Element Locally Valid (Type) (3.3.4).
      *    1.1.2 Neither its [children] nor its [attributes] contains an information item (element or attribute respectively) whose [validity] is invalid.
      *    1.1.3 Neither its [children] nor its [attributes] contains an information item (element or attribute respectively) with a context-determined declaration of mustFind whose [validity] is unknown.
-    , then valid;
-    *    1.2 otherwise invalid.
-    *    2 otherwise notKnown.
-    */
+     * , then valid;
+     *    1.2 otherwise invalid.
+     *    2 otherwise notKnown.
+     * @deprecated; not thread-safe
+     */
     PSVIDefs::Validity getValidity() const;
 
 
@@ -285,27 +307,32 @@ public :
      * 1 If it was strictly assessed and neither its [children] nor its [attributes] contains an information item (element or attribute respectively) whose [validation attempted] is not full, then full;
      * 2 If it was not strictly assessed and neither its [children] nor its [attributes] contains an information item (element or attribute respectively) whose [validation attempted] is not none, then none;
      *3 otherwise partial.
+     * @deprecated; not thread-safe
      */
     PSVIDefs::Validation getValidationAttempted() const;
 
 
     /**
      * @return the complexity. simple or complex, depending on the type definition.
+     * @deprecated; not thread-safe
      */
     PSVIDefs::Complexity getTypeType() const;
 
     /**
      * The target namespace of the type definition.
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
      */
     const XMLCh* getTypeUri() const;
 
     /**
      * The {name} of the type definition, if it is not absent. 
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
      */
     const XMLCh* getTypeName() const;
 
     /**
      * true if the {name} of the type definition is absent, otherwise false.
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
      */
     bool getTypeAnonymous() const;
 
@@ -313,32 +340,43 @@ public :
      * If this method returns true and validity is VALID then the next three 
      * produce accurate results
      * @return true if the element is validated using a union type
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
      */
     bool isTypeDefinitionUnion() const;
 
     /**
      * The {target namespace} of the actual member type definition.
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
      */
     const XMLCh* getMemberTypeUri() const;
 
     /**
      * @return true if the {name} of the actual member type definition is absent, otherwise false.
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
      */
     bool getMemberTypeAnonymous() const;
 
     /**
      * @return the {name} of the actual member type definition, if it is not absent. 
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
      */
     const XMLCh* getMemberTypeName() const;
 
 
+    /**
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
+     */
     virtual const XMLCh* getDOMTypeInfoUri() const;
+    /**
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
+     */
     virtual const XMLCh* getDOMTypeInfoName() const;
 
 
     // -----------------------------------------------------------------------
     //  Setter methods
     // -----------------------------------------------------------------------
+    void setElemId(unsigned int elemId);
     void setModelType(const SchemaElementDecl::ModelTypes toSet);
     void setDatatypeValidator(DatatypeValidator* newDatatypeValidator);
     void setEnclosingScope(const int enclosingScope);
@@ -347,20 +385,39 @@ public :
     void setMiscFlags(const int flags);
     void setDefaultValue(const XMLCh* const value);
     void setComplexTypeInfo(ComplexTypeInfo* const typeInfo);
+    /**
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
+     */
     void setXsiComplexTypeInfo(ComplexTypeInfo* const typeInfo);
+    /**
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
+     */
     void setXsiSimpleTypeInfo(const DatatypeValidator* const dtv);
     void setAttWildCard(SchemaAttDef* const attWildCard);
     void setSubstitutionGroupElem(SchemaElementDecl* const elemDecl);
+    /**
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
+     */
     void setValidity(PSVIDefs::Validity valid);
+    /**
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
+     */
     void setValidationAttempted(PSVIDefs::Validation validation);
     
-    //called when element content of this element was validated
+    /**
+     * called when element content of this element was validated
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
+     */
     void updateValidityFromElement(const XMLElementDecl *decl, Grammar::GrammarType eleGrammar);
     
     //called when attribute content of this element was validated    
+    // @deprecated; should not be needed in a thread-safe implementation
     void updateValidityFromAttribute(const SchemaAttDef *def);
 
-    //cleans up inbetween uses of the SchemaElementDecl. Resets xsiType, Validity etc.
+    /**
+     * cleans up inbetween uses of the SchemaElementDecl. Resets xsiType, Validity etc.
+     * @deprecated; not thread-safe (will not work with xsi:type and shared grammars)
+     */
     void reset();
 
     // -----------------------------------------------------------------------
@@ -370,6 +427,11 @@ public :
     unsigned int getIdentityConstraintCount() const;
     IdentityConstraint* getIdentityConstraintAt(unsigned int index) const;
 
+    /***
+     * Support for Serialization/De-serialization
+     ***/
+    DECL_XSERIALIZABLE(SchemaElementDecl)
+
 private :
     // -----------------------------------------------------------------------
     //  Private data members
@@ -447,6 +509,7 @@ private :
     int                                fFinalSet;
     int                                fBlockSet;
     int                                fMiscFlags;
+    unsigned int                       fElemId;
     XMLCh*                             fDefaultValue;
     ComplexTypeInfo*                   fComplexTypeInfo;
     RefHash2KeysTableOf<SchemaAttDef>* fAttDefs;
@@ -467,10 +530,7 @@ private :
 // ---------------------------------------------------------------------------
 inline ContentSpecNode* SchemaElementDecl::getContentSpec()
 {
-    if (fXsiComplexTypeInfo != 0) {
-        return fXsiComplexTypeInfo->getContentSpec();
-    }
-    else if (fComplexTypeInfo != 0) {
+    if (fComplexTypeInfo != 0) {
         return fComplexTypeInfo->getContentSpec();
     }
 
@@ -479,10 +539,7 @@ inline ContentSpecNode* SchemaElementDecl::getContentSpec()
 
 inline const ContentSpecNode* SchemaElementDecl::getContentSpec() const
 {
-    if (fXsiComplexTypeInfo != 0) {
-        return fXsiComplexTypeInfo->getContentSpec();
-    }
-    else if (fComplexTypeInfo != 0) {
+    if (fComplexTypeInfo != 0) {
         return fComplexTypeInfo->getContentSpec();
     }
 
@@ -497,10 +554,7 @@ SchemaElementDecl::setContentSpec(ContentSpecNode* toAdopt)
 
 inline XMLContentModel* SchemaElementDecl::getContentModel()
 {
-    if (fXsiComplexTypeInfo != 0) {
-        return fXsiComplexTypeInfo->getContentModel();
-    }
-    else if (fComplexTypeInfo != 0) {
+    if (fComplexTypeInfo != 0) {
         return fComplexTypeInfo->getContentModel();
     }
     return 0;
@@ -518,10 +572,7 @@ SchemaElementDecl::setContentModel(XMLContentModel* const newModelToAdopt)
 // ---------------------------------------------------------------------------
 inline SchemaElementDecl::ModelTypes SchemaElementDecl::getModelType() const
 {
-    if (fXsiComplexTypeInfo) {
-        return (SchemaElementDecl::ModelTypes) fXsiComplexTypeInfo->getContentType();
-    }
-    else if (fComplexTypeInfo) {
+    if (fComplexTypeInfo) {
         return (SchemaElementDecl::ModelTypes) fComplexTypeInfo->getContentType();
     }
 
@@ -530,9 +581,6 @@ inline SchemaElementDecl::ModelTypes SchemaElementDecl::getModelType() const
 
 inline DatatypeValidator* SchemaElementDecl::getDatatypeValidator() const
 {
-    if (fXsiComplexTypeInfo) {
-        return fXsiComplexTypeInfo->getDatatypeValidator();
-    }
 
     return fDatatypeValidator;
 }
@@ -564,34 +612,17 @@ inline XMLCh* SchemaElementDecl::getDefaultValue() const
 
 inline ComplexTypeInfo* SchemaElementDecl::getComplexTypeInfo() const
 {
-    if (fXsiComplexTypeInfo) {
-        return fXsiComplexTypeInfo;
-    }
 
     return fComplexTypeInfo;
 }
 
 inline const SchemaAttDef* SchemaElementDecl::getAttWildCard() const {
 
-    if (fXsiComplexTypeInfo) {
-        return fXsiComplexTypeInfo->getAttWildCard();
-    }
-    else if (fComplexTypeInfo) {
-        return fComplexTypeInfo->getAttWildCard();
-    }
-
     return fAttWildCard;
 }
 
 inline SchemaAttDef* SchemaElementDecl::getAttWildCard() {
 
-    if (fXsiComplexTypeInfo) {
-        return fXsiComplexTypeInfo->getAttWildCard();
-    }
-    else if (fComplexTypeInfo) {
-        return fComplexTypeInfo->getAttWildCard();
-    }
-
     return fAttWildCard;
 }
 
@@ -607,6 +638,8 @@ SchemaElementDecl::getSubstitutionGroupElem() const {
 }
 
 inline const XMLCh* SchemaElementDecl::getTypeName() const {
+    // removing fXsi* references would break DOMTypeInfo implementation completely;
+    // will have to wait for now
     if (fXsiComplexTypeInfo)
         return fXsiComplexTypeInfo->getTypeLocalName();
     else if (fComplexTypeInfo) 
@@ -616,12 +649,8 @@ inline const XMLCh* SchemaElementDecl::getTypeName() const {
     else if(fDatatypeValidator)
         return fDatatypeValidator->getTypeLocalName();
 
-    //its anyType if we have not done validation on it
-    if(getValidationAttempted() == PSVIDefs::NONE)
-        return SchemaSymbols::fgATTVAL_ANYTYPE;
-
-
-    return 0;
+    //its anyType if we have not done validation on it or none of the above exist
+    return SchemaSymbols::fgATTVAL_ANYTYPE;
 }
 
 inline PSVIDefs::Complexity SchemaElementDecl::getTypeType() const {
@@ -635,6 +664,8 @@ inline PSVIDefs::Complexity SchemaElementDecl::getTypeType() const {
 
 
 inline const XMLCh* SchemaElementDecl::getTypeUri() const {
+    // removing fXsi* references would break DOMTypeInfo implementation completely;
+    // will have to wait for now
     if (fXsiComplexTypeInfo)
         return fXsiComplexTypeInfo->getTypeUri();
     else if (fComplexTypeInfo)
@@ -644,15 +675,13 @@ inline const XMLCh* SchemaElementDecl::getTypeUri() const {
     else if(fDatatypeValidator)
         return fDatatypeValidator->getTypeUri();
 
-    //its anyType if we have not done validation on it
-    if(getValidationAttempted() == PSVIDefs::NONE)
-        return SchemaSymbols::fgURI_SCHEMAFORSCHEMA;
-
-
-    return 0;
+    //its anyType if we have not done validation on it or none of the above exist
+    return SchemaSymbols::fgURI_SCHEMAFORSCHEMA;
 }
 
 inline const XMLCh* SchemaElementDecl::getMemberTypeName() const {
+    // removing fXsi* references would break DOMTypeInfo implementation completely;
+    // will have to wait for now
     if(fXsiSimpleTypeInfo && fXsiSimpleTypeInfo->getType() == DatatypeValidator::Union)
         return ((UnionDatatypeValidator*)fXsiSimpleTypeInfo)->getMemberTypeName();
     else if(fDatatypeValidator && fDatatypeValidator->getType() == DatatypeValidator::Union)
@@ -661,6 +690,8 @@ inline const XMLCh* SchemaElementDecl::getMemberTypeName() const {
 }
 
 inline const XMLCh* SchemaElementDecl::getMemberTypeUri() const {
+    // removing fXsi* references would break DOMTypeInfo implementation completely;
+    // will have to wait for now
     if(fXsiSimpleTypeInfo && fXsiSimpleTypeInfo->getType() == DatatypeValidator::Union)
         return ((UnionDatatypeValidator*)fXsiSimpleTypeInfo)->getMemberTypeUri();
     if(fDatatypeValidator && fDatatypeValidator->getType() == DatatypeValidator::Union)
@@ -670,6 +701,8 @@ inline const XMLCh* SchemaElementDecl::getMemberTypeUri() const {
 }
 
 inline bool SchemaElementDecl::getMemberTypeAnonymous() const {
+    // removing fXsi* references would break DOMTypeInfo implementation completely;
+    // will have to wait for now
     if(fXsiSimpleTypeInfo && fXsiSimpleTypeInfo->getType() == DatatypeValidator::Union)
         return ((UnionDatatypeValidator*)fXsiSimpleTypeInfo)->getMemberTypeAnonymous();
     else if(fDatatypeValidator && fDatatypeValidator->getType() == DatatypeValidator::Union)
@@ -678,6 +711,8 @@ inline bool SchemaElementDecl::getMemberTypeAnonymous() const {
 }
 
 inline bool SchemaElementDecl::isTypeDefinitionUnion() const {
+    // removing fXsi* references would break DOMTypeInfo implementation completely;
+    // will have to wait for now
    if(fXsiSimpleTypeInfo && fXsiSimpleTypeInfo->getType() == DatatypeValidator::Union ||
       fDatatypeValidator && fDatatypeValidator->getType() == DatatypeValidator::Union)
        return true;
@@ -718,10 +753,12 @@ inline bool SchemaElementDecl::getTypeAnonymous() const {
         return fDatatypeValidator->getAnonymous();
     }
 
-    return true;
+    return false;
 }
 
 inline const XMLCh* SchemaElementDecl::getDOMTypeInfoName() const {
+    // removing fXsi* references would break DOMTypeInfo implementation completely;
+    // will have to wait for now
     if(fValidity != PSVIDefs::VALID) {
         if(getTypeType() == PSVIDefs::SIMPLE)
             return SchemaSymbols::fgDT_ANYSIMPLETYPE;
@@ -740,6 +777,8 @@ inline const XMLCh* SchemaElementDecl::getDOMTypeInfoName() const {
 
 inline const XMLCh* SchemaElementDecl::getDOMTypeInfoUri() const {
 
+    // removing fXsi* references would break DOMTypeInfo implementation completely;
+    // will have to wait for now
     if(fValidity != PSVIDefs::VALID)
         return SchemaSymbols::fgURI_SCHEMAFORSCHEMA;
 
@@ -759,6 +798,12 @@ inline const XMLCh* SchemaElementDecl::getDOMTypeInfoUri() const {
 // ---------------------------------------------------------------------------
 //  SchemaElementDecl: Setter methods
 // ---------------------------------------------------------------------------
+inline void
+SchemaElementDecl::setElemId(unsigned int elemId)
+{
+    fElemId = elemId;
+}
+
 inline void
 SchemaElementDecl::setModelType(const SchemaElementDecl::ModelTypes toSet)
 {
