@@ -56,6 +56,12 @@
 
 /*
  * $Log: SubstitutionGroupComparator.cpp,v $
+ * Revision 1.8  2003/07/31 17:14:27  peiyongz
+ * Grammar embed grammar description
+ *
+ * Revision 1.7  2003/06/25 22:38:18  peiyongz
+ * to use new GrammarResolver::getGrammar()
+ *
  * Revision 1.6  2003/01/13 20:16:51  knoaman
  * [Bug 16024] SchemaSymbols.hpp conflicts C++ Builder 6 dir.h
  *
@@ -112,6 +118,8 @@
 // ---------------------------------------------------------------------------
 //  Includes
 // ---------------------------------------------------------------------------
+#include <xercesc/framework/XMLGrammarPool.hpp>
+#include <xercesc/framework/XMLSchemaDescription.hpp>
 #include <xercesc/validators/schema/SubstitutionGroupComparator.hpp>
 #include <xercesc/validators/common/Grammar.hpp>
 #include <xercesc/validators/schema/SchemaGrammar.hpp>
