@@ -56,6 +56,15 @@
 
 /*
  * $Log: XercesXPath.cpp,v $
+ * Revision 1.11  2003/10/17 21:18:04  peiyongz
+ * using XTemplateSerializer
+ *
+ * Revision 1.10  2003/10/14 15:24:23  peiyongz
+ * Implementation of Serialization/Deserialization
+ *
+ * Revision 1.9  2003/10/01 16:32:42  neilg
+ * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
+ *
  * Revision 1.8  2003/05/18 14:02:09  knoaman
  * Memory manager implementation: pass per instance manager.
  *
@@ -103,6 +112,9 @@
 #include <xercesc/framework/XMLBuffer.hpp>
 #include <xercesc/internal/XMLReader.hpp>
 #include <xercesc/util/RuntimeException.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
+
+#include <xercesc/internal/XTemplateSerializer.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -155,6 +167,33 @@ XercesNodeTest::XercesNodeTest(const XercesNodeTest& other)
 {
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(XercesNodeTest)
+
+void XercesNodeTest::serialize(XSerializeEngine& serEng)
+{
+
+    if (serEng.isStoring())
+    {
+        serEng<<fType;
+        serEng<<fName;
+    }
+    else
+    {
+        serEng>>fType;
+        serEng>>fName;
+    }
+}
+
+XercesNodeTest::XercesNodeTest(MemoryManager* const manager)
+:fType(UNKNOWN)
+,fName(0)
+{
+}
+
 // ---------------------------------------------------------------------------
 //  XercesNodeTest: Operators
 // ---------------------------------------------------------------------------
@@ -236,6 +275,32 @@ bool XercesStep::operator!=(const XercesStep& other) const {
     return !operator==(other);
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(XercesStep)
+
+void XercesStep::serialize(XSerializeEngine& serEng)
+{
+    if (serEng.isStoring())
+    {
+        serEng<<fAxisType;
+        serEng<<fNodeTest;
+    }
+    else
+    {
+        serEng>>fAxisType;
+        serEng>>fNodeTest;
+    }
+}
+
+XercesStep::XercesStep(MemoryManager* const manager)
+:fAxisType(UNKNOWN)
+,fNodeTest(0)
+{
+}
+
 // ---------------------------------------------------------------------------
 //  XercesLocationPath: Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -267,6 +332,35 @@ bool XercesLocationPath::operator!=(const XercesLocationPath& other) const {
     return !operator==(other);
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(XercesLocationPath)
+
+void XercesLocationPath::serialize(XSerializeEngine& serEng)
+{
+    if (serEng.isStoring())
+    {
+        /***
+         * Serialize RefVectorOf<XercesStep>* fSteps;
+         ***/
+        XTemplateSerializer::storeObject(fSteps, serEng);
+    }
+    else
+    {
+        /***
+         * Deserialize RefVectorOf<XercesStep>* fSteps;
+         ***/
+        XTemplateSerializer::loadObject(&fSteps, 8, true, serEng);
+    }
+}
+
+XercesLocationPath::XercesLocationPath(MemoryManager* const manager)
+:fSteps(0)
+{
+}
+
 // ---------------------------------------------------------------------------
 //  XercesPath: Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -290,6 +384,10 @@ XercesXPath::XercesXPath(const XMLCh* const xpathExpr,
             checkForSelectedAttributes();
         }
     }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch(...) {
 
         cleanUp();
@@ -618,6 +716,45 @@ void XercesXPath::parseExpression(XMLStringPool* const stringPool,
     janSteps.orphan();
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(XercesXPath)
+
+void XercesXPath::serialize(XSerializeEngine& serEng)
+{
+
+    if (serEng.isStoring())
+    {
+        serEng<<fEmptyNamespaceId;
+        serEng.writeString(fExpression);
+
+        /***
+         * Serialize RefVectorOf<XercesLocationPath>* fLocationPaths;
+         ***/
+        XTemplateSerializer::storeObject(fLocationPaths, serEng);
+    }
+    else
+    {
+        serEng>>fEmptyNamespaceId;
+        serEng.readString(fExpression);
+
+        /***
+         * Deserialize RefVectorOf<XercesLocationPath>* fLocationPaths;
+         ***/
+        XTemplateSerializer::loadObject(&fLocationPaths, 8, true, serEng);
+    }
+}
+
+XercesXPath::XercesXPath(MemoryManager* const manager)
+:fEmptyNamespaceId(0)
+,fExpression(0)
+,fLocationPaths(0)
+,fMemoryManager(manager)
+{
+}
+
 // ---------------------------------------------------------------------------
 //  XPathScanner: Constructors and Destructor
 // ---------------------------------------------------------------------------
