@@ -66,6 +66,15 @@
 
 /**
  * $Log: Traversal.cpp,v $
+ * Revision 1.15  2003/02/05 18:55:20  tng
+ * [Bug 11915] Utility for freeing memory.
+ *
+ * Revision 1.14  2002/11/12 17:52:12  tng
+ * Test update: do not issue "Test Run Successfully" if there was an error.
+ *
+ * Revision 1.13  2002/11/05 21:47:36  tng
+ * Explicit code using namespace in application.
+ *
  * Revision 1.12  2002/06/25 16:23:16  tng
  * DOM L3: use release()
  *
@@ -118,12 +127,18 @@
 #include <xercesc/util/XMLUniDefs.hpp>
 
 
+XERCES_CPP_NAMESPACE_USE
+
+bool errorOccurred = false;
+
 #define TASSERT(c) tassert((c), __FILE__, __LINE__)
 
 void tassert(bool c, const char *file, int line)
 {
-    if (!c)
+    if (!c) {
         printf("Failure.  Line %d,   file %s\n", line, file);
+        errorOccurred = true;
+    }
 };
 
 
@@ -132,14 +147,18 @@ void tassert(bool c, const char *file, int line)
     try {                                                           \
     operation;                                                      \
     printf(" Error: no exception thrown at line %d\n", __LINE__);   \
-}                                                                   \
+    errorOccurred = true;                                           \
+    }                                                               \
     catch (DOMException &e) {                                       \
-    if (e.code != expected_exception)                       \
-    printf(" Wrong exception code: %d at line %d\n", e.code, __LINE__); \
-}                                                                 \
+    if (e.code != expected_exception) {                             \
+        printf(" Wrong exception code: %d at line %d\n", e.code, __LINE__); \
+        errorOccurred = true;                                       \
+    }                                                               \
+    }                                                               \
     catch (...)   {                                                 \
-    printf(" Wrong exception thrown at line %d\n", __LINE__);       \
-}                                                                   \
+        printf(" Wrong exception thrown at line %d\n", __LINE__);   \
+        errorOccurred = true;                                       \
+    }                                                               \
 }
 
 class  MyFilter : public DOMNodeFilter {
@@ -187,7 +206,7 @@ int  main()
         char *pMessage = XMLString::transcode(toCatch.getMessage());
         fprintf(stderr, "Error during XMLPlatformUtils::Initialize(). \n"
                         "  Message is: %s\n", pMessage);
-        delete [] pMessage;
+        XMLString::release(&pMessage);
         return -1;
     }
 
@@ -609,6 +628,11 @@ int  main()
     // And call the termination method
     XMLPlatformUtils::Terminate();
 
+    if (errorOccurred) {
+        printf("Test Failed\n");
+        return 4;
+    }
+
     printf("Test Run Successfully\n");
     return 0;
 };
